@@ -1,3 +1,8 @@
+import * as React from 'react';
+import * as classNames from 'classnames';
+
+import { ALL_NAMESPACES_KEY } from '../../const';
+
 // Kubernetes "dns-friendly" names match
 // [a-z0-9]([-a-z0-9]*[a-z0-9])?  and are 63 or fewer characters
 // long. This pattern checks the pattern but not the length.
@@ -8,13 +13,12 @@
 //    new RegExp("PREFIX" + legalNamePattern.source + "(SUFFIX)")
 //
 // And it's ok for users to make assumptions about capturing groups.
-import { ALL_NAMESPACES_KEY } from '../../const';
 
 export const legalNamePattern = /[a-z0-9](?:[-a-z0-9]*[a-z0-9])?/;
 
 const basePathPattern = new RegExp(`^/?${window.SERVER_FLAGS.basePath}`);
 
-export const namespacedPrefixes = ['/search', '/status', '/k8s'];
+export const namespacedPrefixes = ['/search', '/status', '/k8s', '/overview', '/catalog', '/provisionedservices', '/operators', '/operatormanagement', '/operatorhub'];
 
 export const stripBasePath = path => path.replace(basePathPattern, '/');
 
@@ -43,3 +47,14 @@ export const getNamespace = path => {
   const match = ns.match(legalNamePattern);
   return match && match.length > 0 && match[0];
 };
+
+export const ExternalLink = ({href, text, additionalClassName=''}) => <a className={classNames('co-external-link', additionalClassName)} href={href} target="_blank" rel="noopener noreferrer">{text}</a>;
+
+export const getURLSearchParams = () => {
+  const all = {};
+  const params = new URLSearchParams(window.location.search);
+  for (const [k, v] of params.entries()) {
+    all[k] = v;
+  }
+  return all;
+};
